Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src\derivepassphrase\__init__.py | (no class) | 3 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\__init__.py | (no class) | 5 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_helpers.py | ConfigurationMutex | 39 | 8 | 0 | 2 | 1 | 78.049%
src\derivepassphrase\_internals\cli_helpers.py | (no class) | 275 | 0 | 27 | 56 | 1 | 99.698%
src\derivepassphrase\_internals\cli_machinery.py | ClickEchoStderrHandler | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | CLIofPackageFormatter | 14 | 0 | 5 | 6 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | StandardCLILogging | 2 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | StandardLoggingContextManager | 12 | 0 | 0 | 4 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | StandardWarningsLoggingContextManager | 14 | 0 | 2 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | OptionGroupOption | 6 | 0 | 1 | 2 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | CommandWithHelpGroups | 73 | 0 | 14 | 32 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | DefaultToVaultGroup | 12 | 0 | 3 | 4 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | ZshComplete | 3 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_internals\cli_machinery.py | (no class) | 202 | 0 | 11 | 32 | 0 | 100.000%
src\derivepassphrase\_internals\cli_messages.py | DebugTranslations | 22 | 0 | 13 | 8 | 0 | 100.000%
src\derivepassphrase\_internals\cli_messages.py | TranslatableString | 38 | 0 | 7 | 14 | 0 | 100.000%
src\derivepassphrase\_internals\cli_messages.py | TranslatedString | 25 | 0 | 12 | 8 | 0 | 100.000%
src\derivepassphrase\_internals\cli_messages.py | (no class) | 392 | 0 | 352 | 0 | 0 | 100.000%
src\derivepassphrase\_types.py | _VaultConfigValidator | 96 | 0 | 3 | 66 | 0 | 100.000%
src\derivepassphrase\_types.py | SSHKeyCommentPair | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_types.py | StoreroomKeyPair | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_types.py | StoreroomMasterKeys | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\_types.py | (no class) | 174 | 0 | 52 | 2 | 0 | 100.000%
src\derivepassphrase\cli.py | _VaultContext | 324 | 0 | 1 | 144 | 0 | 100.000%
src\derivepassphrase\cli.py | (no class) | 142 | 0 | 8 | 12 | 0 | 100.000%
src\derivepassphrase\exporter\__init__.py | NotAVaultConfigError | 2 | 0 | 8 | 0 | 0 | 100.000%
src\derivepassphrase\exporter\__init__.py | (no class) | 44 | 0 | 23 | 12 | 0 | 100.000%
src\derivepassphrase\exporter\storeroom.py | (no class) | 207 | 0 | 24 | 38 | 0 | 100.000%
src\derivepassphrase\exporter\vault_native.py | VaultNativeConfigParser | 82 | 0 | 3 | 8 | 0 | 100.000%
src\derivepassphrase\exporter\vault_native.py | VaultNativeV03ConfigParser | 12 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\exporter\vault_native.py | VaultNativeV02ConfigParser | 35 | 0 | 0 | 2 | 0 | 100.000%
src\derivepassphrase\exporter\vault_native.py | (no class) | 75 | 0 | 33 | 4 | 0 | 100.000%
src\derivepassphrase\sequin.py | Sequin | 92 | 0 | 0 | 44 | 0 | 100.000%
src\derivepassphrase\sequin.py | SequinExhaustedError | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\sequin.py | (no class) | 16 | 0 | 2 | 0 | 0 | 100.000%
src\derivepassphrase\ssh_agent\__init__.py | TrailingDataError | 1 | 0 | 0 | 0 | 0 | 100.000%
src\derivepassphrase\ssh_agent\__init__.py | SSHAgentFailedError | 2 | 0 | 9 | 0 | 0 | 100.000%
src\derivepassphrase\ssh_agent\__init__.py | SSHAgentClient | 143 | 4 | 13 | 42 | 1 | 97.297%
src\derivepassphrase\ssh_agent\__init__.py | (no class) | 39 | 0 | 32 | 0 | 0 | 100.000%
src\derivepassphrase\ssh_agent\socketprovider.py | SocketProvider | 59 | 9 | 5 | 28 | 2 | 85.057%
src\derivepassphrase\ssh_agent\socketprovider.py | (no class) | 26 | 0 | 3 | 0 | 0 | 100.000%
src\derivepassphrase\vault.py | Vault | 121 | 2 | 0 | 40 | 1 | 98.137%
src\derivepassphrase\vault.py | (no class) | 33 | 0 | 3 | 0 | 0 | 100.000%
tests\__init__.py | SSHTestKey | 1 | 0 | 0 | 0 | 0 | 100.000%
tests\__init__.py | FakeSSHAgentSocket | 71 | 4 | 0 | 34 | 3 | 93.333%
tests\__init__.py | FakeSSHAgentSocketWithAddress | 15 | 0 | 0 | 6 | 0 | 100.000%
tests\__init__.py | ReadableResult | 7 | 0 | 0 | 2 | 0 | 100.000%
tests\__init__.py | CliRunner | 13 | 0 | 2 | 0 | 0 | 100.000%
tests\__init__.py | (no class) | 424 | 0 | 93 | 50 | 0 | 100.000%
tests\conftest.py | (no class) | 58 | 4 | 423 | 2 | 0 | 93.333%
tests\test_derivepassphrase_cli.py | ListKeysAction | 6 | 0 | 1 | 4 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | SignAction | 4 | 0 | 1 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | SocketAddressAction | 4 | 0 | 3 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | SystemSupportAction | 16 | 3 | 22 | 6 | 0 | 86.364%
tests\test_derivepassphrase_cli.py | TestAllCLI | 106 | 0 | 0 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | TestCLI | 552 | 18 | 1 | 10 | 0 | 96.797%
tests\test_derivepassphrase_cli.py | TestCLIUtils | 218 | 0 | 11 | 18 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | TestCLIUtils.test_400_key_to_phrase.ErrCallback | 3 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | TestCLITransition | 103 | 0 | 0 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | ConfigManagementStateMachine | 69 | 0 | 0 | 16 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | FakeConfigurationMutexStateMachine | 129 | 0 | 20 | 20 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | FakeConfigurationMutexStateMachine.ConfigurationMutexStub | 12 | 0 | 9 | 0 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | TestShellCompletion | 63 | 0 | 0 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | TestShellCompletion.Completions | 6 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_cli.py | (no class) | 560 | 0 | 22 | 48 | 0 | 100.000%
tests\test_derivepassphrase_cli_export_vault.py | TestCLI | 63 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_cli_export_vault.py | TestStoreroom | 58 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_cli_export_vault.py | TestVaultNativeConfig | 32 | 0 | 3 | 2 | 0 | 100.000%
tests\test_derivepassphrase_cli_export_vault.py | (no class) | 67 | 0 | 4 | 0 | 0 | 100.000%
tests\test_derivepassphrase_exporter.py | Test001ExporterUtils | 49 | 0 | 16 | 6 | 0 | 100.000%
tests\test_derivepassphrase_exporter.py | Test001ExporterUtils.VaultKeyEnvironment | 9 | 0 | 0 | 4 | 0 | 100.000%
tests\test_derivepassphrase_exporter.py | Test002CLI | 14 | 0 | 0 | 2 | 0 | 100.000%
tests\test_derivepassphrase_exporter.py | (no class) | 62 | 0 | 2 | 0 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | TestStaticFunctionality | 21 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | TestStaticFunctionality.BigEndianNumberTest | 7 | 0 | 4 | 0 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | TestSequin | 35 | 0 | 1 | 14 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | TestSequin.ConstructorTestCase | 21 | 1 | 0 | 10 | 1 | 93.548%
tests\test_derivepassphrase_sequin.py | TestSequin.GenerationSequence | 2 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | TestSequin.ShiftSequence | 13 | 0 | 0 | 4 | 0 | 100.000%
tests\test_derivepassphrase_sequin.py | (no class) | 97 | 0 | 5 | 4 | 0 | 100.000%
tests\test_derivepassphrase_ssh_agent.py | TestTestingMachineryFakeSSHAgentSocket | 50 | 0 | 0 | 6 | 0 | 100.000%
tests\test_derivepassphrase_ssh_agent.py | TestStaticFunctionality | 111 | 6 | 3 | 14 | 0 | 95.200%
tests\test_derivepassphrase_ssh_agent.py | TestAgentInteraction | 127 | 5 | 17 | 12 | 0 | 94.964%
tests\test_derivepassphrase_ssh_agent.py | TestAgentInteraction.test_310_truncated_server_response.PseudoSocket | 2 | 0 | 0 | 0 | 0 | 100.000%
tests\test_derivepassphrase_ssh_agent.py | (no class) | 130 | 0 | 3 | 2 | 0 | 100.000%
tests\test_derivepassphrase_types.py | (no class) | 60 | 0 | 4 | 4 | 0 | 100.000%
tests\test_derivepassphrase_vault.py | TestVault | 98 | 0 | 6 | 24 | 0 | 100.000%
tests\test_derivepassphrase_vault.py | (no class) | 96 | 0 | 3 | 0 | 0 | 100.000%
tests\test_l10n.py | TestL10nMachineryWithDebugTranslations | 67 | 0 | 6 | 2 | 0 | 100.000%
tests\test_l10n.py | (no class) | 60 | 0 | 2 | 2 | 0 | 100.000%
Total |  | 6658 | 64 | 1458 | 948 | 10 | 98.974%

No items found using the specified filter.

57 empty classes skipped.